pub struct Random {
pub rng: SmallRng,
}Expand description
Random represents a PRNG.
It is a reimplementation of quickcheck::Gen, which does not export the
methods we need to properly generate random values.
It is unspecified whether this is a secure RNG or not. Therefore, callers should assume it is insecure.
Fields
rng: SmallRngImplementations
Sourceimpl Random
impl Random
pub fn arbitrary<T: Arbitrary>(&self) -> T
pub fn from_seed(seed: u64) -> Self
Sourcepub fn choose<'a, T>(&mut self, slice: &'a [T]) -> Option<&'a T>
pub fn choose<'a, T>(&mut self, slice: &'a [T]) -> Option<&'a T>
Choose among the possible alternatives in the slice given. If the slice
is empty, then None is returned. Otherwise, a non-None value is
guaranteed to be returned.
pub fn gen<T>(&mut self) -> Twhere
Standard: Distribution<T>,
pub fn gen_range<T, R>(&mut self, range: R) -> Twhere
T: SampleUniform,
R: SampleRange<T>,